#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIGNNZ_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIGNNZ_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/signnz.hpp>

#endif
